Input files are created with Bismark as follows (from the
command line): bismark_methylation_extractor -s --comprehensive test_sample.sam
bismark2bedGraph -o CpG_context_test_sample.bedGraph
CpG_context_test_sample.txt
This will output two files, a .bedGraph and a .cov file.
We will import the CpG_context_test_sample.cov using readBismark.
The colData argument should specify the sample names as
character. Alternatively, a data.frame or
DataFrame can be given. Then, the row names are used as
sample names and the data frame is passed to the final
BSraw object.